This is an automated email from the ASF dual-hosted git repository.
lidavidm pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/arrow-adbc.git
The following commit(s) were added to refs/heads/main by this push:
new 062e4d463 test(python/adbc_driver_manager): relax exception message
check (#2112)
062e4d463 is described below
commit 062e4d46307e544c04f1723af1bac088be66d61a
Author: David Li <[email protected]>
AuthorDate: Mon Sep 2 11:35:27 2024 +0900
test(python/adbc_driver_manager): relax exception message check (#2112)
Fixes #2111.
---
ci/conda_env_python.txt | 5 ++---
docs/source/python/recipe/postgresql_polars.py | 4 ++--
python/adbc_driver_manager/tests/test_lowlevel.py | 4 ++--
3 files changed, 6 insertions(+), 7 deletions(-)
diff --git a/ci/conda_env_python.txt b/ci/conda_env_python.txt
index cf2abeeec..8be410973 100644
--- a/ci/conda_env_python.txt
+++ b/ci/conda_env_python.txt
@@ -20,13 +20,12 @@ importlib-resources
# nodejs is required by pyright
nodejs >=13.0.0
pandas
-pyarrow=15.0.2
+pyarrow-all
pyright
pytest
setuptools
# For integration testing
-# 0.20.3 is broken on conda-forge
-polars<=0.20.2
+polars
protobuf
python-duckdb
diff --git a/python/adbc_driver_manager/tests/test_lowlevel.py
b/python/adbc_driver_manager/tests/test_lowlevel.py
index d2940aef1..e68ea444a 100644
--- a/python/adbc_driver_manager/tests/test_lowlevel.py
+++ b/python/adbc_driver_manager/tests/test_lowlevel.py
@@ -428,7 +428,7 @@ def test_pycapsule(sqlite):
handle = conn.get_table_schema(catalog=None, db_schema=None,
table_name="foo")
assert data.schema == pyarrow.schema(handle)
# ensure consumed schema was marked as such
- with pytest.raises(ValueError, match="Cannot import released ArrowSchema"):
+ with pytest.raises(ValueError):
pyarrow.schema(handle)
# smoke test for the capsule calling release
@@ -454,7 +454,7 @@ def test_pycapsule(sqlite):
assert result == table
# ensure consumed schema was marked as such
- with pytest.raises(ValueError, match="Cannot import released
ArrowArrayStream"):
+ with pytest.raises(ValueError):
pyarrow.table(handle)
# smoke test for the capsule calling release
diff --git a/docs/source/python/recipe/postgresql_polars.py
b/docs/source/python/recipe/postgresql_polars.py
index 22829ee02..cf5525924 100644
--- a/docs/source/python/recipe/postgresql_polars.py
+++ b/docs/source/python/recipe/postgresql_polars.py
@@ -48,9 +48,9 @@ data = pl.DataFrame(
data.write_database("example", uri, engine="adbc", if_table_exists="replace")
#: After creating the table, we can use
#: :external:py:func:`polars.read_database` to fetch the result. Again,
#: we can just pass the URI and tell Polars to manage ADBC for us.
-df = pl.read_database("SELECT * FROM example WHERE ints > 1", uri,
engine="adbc")
+df = pl.read_database_uri("SELECT * FROM example WHERE ints > 1", uri,
engine="adbc")
assert len(df) == 2
@@ -48,9 +48,9 @@ data = pl.DataFrame(
data.write_database("example", uri, engine="adbc", if_table_exists="replace")
#: After creating the table, we can use
-#: :external:py:func:`polars.read_database` to fetch the result. Again,
+#: :external:py:func:`polars.read_database_uri` to fetch the result. Again,
#: we can just pass the URI and tell Polars to manage ADBC for us.